@@ -16,18 +16,18 @@
 from collections import OrderedDict
 import os
 import re
-from typing import Dict, Optional, Sequence, Tuple, Type, Union
-import pkg_resources
+from typing import Dict, Mapping, Optional, Sequence, Tuple, Type, Union
 
 from google.api_core import client_options as client_options_lib
 from google.api_core import exceptions as core_exceptions
 from google.api_core import gapic_v1
 from google.api_core import retry as retries
 from google.auth import credentials as ga_credentials  # type: ignore
+from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
-from google.auth.exceptions import MutualTLSChannelError  # type: ignore
 from google.oauth2 import service_account  # type: ignore
+import pkg_resources
 
 try:
     OptionalRetry = Union[retries.Retry, gapic_v1.method._MethodDefault]
@@ -36,10 +36,12 @@ except AttributeError:  # pragma: NO COVER
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
+
 from google.cloud.vpcaccess_v1.services.vpc_access_service import pagers
 from google.cloud.vpcaccess_v1.types import vpc_access
-from google.protobuf import empty_pb2  # type: ignore
-from .transports.base import VpcAccessServiceTransport, DEFAULT_CLIENT_INFO
+
+from .transports.base import DEFAULT_CLIENT_INFO, VpcAccessServiceTransport
 from .transports.grpc import VpcAccessServiceGrpcTransport
 from .transports.grpc_asyncio import VpcAccessServiceGrpcAsyncIOTransport
 
@@ -58,7 +60,10 @@ class VpcAccessServiceClientMeta(type):
     _transport_registry["grpc"] = VpcAccessServiceGrpcTransport
     _transport_registry["grpc_asyncio"] = VpcAccessServiceGrpcAsyncIOTransport
 
-    def get_transport_class(cls, label: str = None,) -> Type[VpcAccessServiceTransport]:
+    def get_transport_class(
+        cls,
+        label: str = None,
+    ) -> Type[VpcAccessServiceTransport]:
         """Returns an appropriate transport class.
 
         Args:
@@ -166,10 +171,16 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
         return self._transport
 
     @staticmethod
-    def connector_path(project: str, location: str, connector: str,) -> str:
+    def connector_path(
+        project: str,
+        location: str,
+        connector: str,
+    ) -> str:
         """Returns a fully-qualified connector string."""
         return "projects/{project}/locations/{location}/connectors/{connector}".format(
-            project=project, location=location, connector=connector,
+            project=project,
+            location=location,
+            connector=connector,
         )
 
     @staticmethod
@@ -182,7 +193,9 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_billing_account_path(billing_account: str,) -> str:
+    def common_billing_account_path(
+        billing_account: str,
+    ) -> str:
         """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
@@ -195,9 +208,13 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_folder_path(folder: str,) -> str:
+    def common_folder_path(
+        folder: str,
+    ) -> str:
         """Returns a fully-qualified folder string."""
-        return "folders/{folder}".format(folder=folder,)
+        return "folders/{folder}".format(
+            folder=folder,
+        )
 
     @staticmethod
     def parse_common_folder_path(path: str) -> Dict[str, str]:
@@ -206,9 +223,13 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_organization_path(organization: str,) -> str:
+    def common_organization_path(
+        organization: str,
+    ) -> str:
         """Returns a fully-qualified organization string."""
-        return "organizations/{organization}".format(organization=organization,)
+        return "organizations/{organization}".format(
+            organization=organization,
+        )
 
     @staticmethod
     def parse_common_organization_path(path: str) -> Dict[str, str]:
@@ -217,9 +238,13 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_project_path(project: str,) -> str:
+    def common_project_path(
+        project: str,
+    ) -> str:
         """Returns a fully-qualified project string."""
-        return "projects/{project}".format(project=project,)
+        return "projects/{project}".format(
+            project=project,
+        )
 
     @staticmethod
     def parse_common_project_path(path: str) -> Dict[str, str]:
@@ -228,10 +253,14 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
         return m.groupdict() if m else {}
 
     @staticmethod
-    def common_location_path(project: str, location: str,) -> str:
+    def common_location_path(
+        project: str,
+        location: str,
+    ) -> str:
         """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
-            project=project, location=location,
+            project=project,
+            location=location,
         )
 
     @staticmethod
@@ -419,7 +448,6 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
         r"""Creates a Serverless VPC Access connector, returns an
         operation.
 
-
         .. code-block:: python
 
             from google.cloud import vpcaccess_v1
@@ -519,7 +547,12 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
@@ -544,7 +577,6 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
         r"""Gets a Serverless VPC Access connector. Returns NOT_FOUND if the
         resource does not exist.
 
-
         .. code-block:: python
 
             from google.cloud import vpcaccess_v1
@@ -619,7 +651,12 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Done; return the response.
         return response
@@ -713,12 +750,20 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # This method is paged; wrap the response in a pager, which provides
         # an `__iter__` convenience method.
         response = pagers.ListConnectorsPager(
-            method=rpc, request=request, response=response, metadata=metadata,
+            method=rpc,
+            request=request,
+            response=response,
+            metadata=metadata,
         )
 
         # Done; return the response.
@@ -736,7 +781,6 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
         r"""Deletes a Serverless VPC Access connector. Returns NOT_FOUND if
         the resource does not exist.
 
-
         .. code-block:: python
 
             from google.cloud import vpcaccess_v1
@@ -828,7 +872,12 @@ class VpcAccessServiceClient(metaclass=VpcAccessServiceClientMeta):
         )
 
         # Send the request.
-        response = rpc(request, retry=retry, timeout=timeout, metadata=metadata,)
+        response = rpc(
+            request,
+            retry=retry,
+            timeout=timeout,
+            metadata=metadata,
+        )
 
         # Wrap the response in an operation future.
         response = operation.from_gapic(
